==> blackbaud_sky_api-7.x-1.0-rc1.tar.gz: blackbaud_sky_api/src/BlackbaudAPI.php <==
<?php

namespace Drupal\blackbaud_sky_api;

use Drupal\blackbaud_sky_api\Blackbaud;

/**
 * Class BlackbaudAPI.
 *
 * @package Drupal\blackbaud_sky_api
 */
class BlackbaudAPI extends Blackbaud {

  /**
   * Get the Developer Key.
   * The bb-api-subscription-key
   *
   * @return string
   *   The Developer Key.
   */
  protected function getDevKey() {
    return variable_get('blackbaud_sky_api_dev_key', '');
  }

  /**
   * Get the API base URL we are checking.
   *
   * @return string
   *   The OAuth base URL.
   */
  protected function getAPIBaseURL() {
    return variable_get('blackbaud_sky_api_url', BLACKBAUD_SKY_API_URL);
  }

  /**
   * Sets the typical headers needed for an api call.
   *
   * @return array
   *   the headers for the api call.
   */
  protected function setAPIHeaders() {
    // Grab the access token.
    $token = parent::getToken('access');

    // Return the set headers for an API call.
    return array(
      'headers' => array(
        'bb-api-subscription-key' => $this->getDevKey(),
        'Authorization' => 'Bearer ' . $token,
      ),
    );
  }
  /**
   * Pings a simple api call to test if the token is valid.
   *
   * @return boolean
   *   If we are able to ping the API or not.
   */
  public function checkToken() {
    // Set up the test API Call.
    $url = $this->getAPIBaseURL() . '/constituent/v1/addresstypes';
    parent::setURL($url);
    parent::requestResponse('GET', $this->setAPIHeaders());

    // Exit if Empty Response.
    if (is_null($this->request)) {
      return FALSE;
    }

    // Check the Body and return as needed.
    $contents = json_decode($this->request->getBody()->getContents());
    return !empty($contents) ? TRUE : FALSE;
  }

}

==> blackbaud_sky_api-7.x-1.1.tar.gz: blackbaud_sky_api/src/BlackbaudAPI.php <==
<?php

namespace Drupal\blackbaud_sky_api;

use Drupal\blackbaud_sky_api\Blackbaud;

/**
 * Class BlackbaudAPI.
 *
 * @package Drupal\blackbaud_sky_api
 */
class BlackbaudAPI extends Blackbaud {

  /**
   * Get the Developer Key.
   * The bb-api-subscription-key
   *
   * @return string
   *   The Developer Key.
   */
  protected function getDevKey() {
    return variable_get('blackbaud_sky_api_dev_key', '');
  }

  /**
   * Get the API base URL we are checking.
   *
   * @return string
   *   The OAuth base URL.
   */
  protected function getAPIBaseURL() {
    return variable_get('blackbaud_sky_api_url', BLACKBAUD_SKY_API_URL);
  }

  /**
   * Sets the typical headers needed for an api call.
   *
   * @return array
   *   the headers for the api call.
   */
  protected function setAPIHeaders() {
    // Grab the access token.
    $token = parent::getToken('access');

    // Return the set headers for an API call.
    return array(
      'headers' => array(
        'bb-api-subscription-key' => $this->getDevKey(),
        'Authorization' => 'Bearer ' . $token,
      ),
    );
  }

  /**
   * Mechanism to call the API.
   *
   * @param string $endpoint
   *   The endpoint url without the BASEapi url
   *
   * @return null|object
   *   The API response or NULL.
   */
  public function callAPI($endpoint) {
    // Set up the test API Call.
    $url = $this->getAPIBaseURL() . '/constituent/v1/addresstypes';
    parent::setURL($url);
    parent::requestResponse('GET', $this->setAPIHeaders());

    // Exit if Empty Response.
    if (is_null($this->request)) {
      return NULL;
    }

    // Grab the Body and return as needed.
    $contents = json_decode($this->request->getBody()->getContents());
    return !empty($contents) ? $contents : NULL;
  }

  /**
   * Pings a simple api call to test if the token is valid.
   *
   * @return boolean
   *   If we are able to ping the API or not.
   */
  public function checkToken() {
    $check = $this->callAPI('/constituent/v1/addresstypes');
    return is_null($check) ? FALSE : TRUE;
  }
}
